#
# spec file for package libixion
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libixion-0_13-0
Name:           libixion
Version:        0.13.0
Release:        2.3.1
Summary:        Threaded multi-target formula parser & interpreter
License:        MIT
Group:          Productivity/Publishing/Word
Url:            https://gitlab.com/ixion/ixion
Source:         http://kohei.us/files/ixion/src/%{name}-%{version}.tar.xz
BuildRequires:  coreutils
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(mdds-1.2)
BuildRequires:  pkgconfig(python3)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_thread-devel
%else
BuildRequires:  boost-devel
%endif

%description
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

%package -n %{libname}
Summary:        Threaded multi-target formula parser & interpreter
Group:          System/Libraries

%description -n %{libname}
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

%package devel
Summary:        Threaded multi-target formula parser & interpreter
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
Ixion is a general purpose formula parser & interpreter that can calculate
multiple named targets, or "cells".

%package tools
Summary:        Spreadsheet file processing library
Group:          Productivity/Publishing/Word
Requires:       %{libname} = %{version}

%description tools
Tools to use ixion parser and interpreter from cli.

%package -n python3-%{name}
Summary:        Python bindings for libixion
Group:          Productivity/Publishing/Word
Obsoletes:      %{name}-python
# Renamed in 15.0
Provides:       %{name}-python3 = %{version}

%description -n python3-%{name}
Python 3 bindings for %{name}.

%prep
%setup -q

%build
%configure \
	--disable-silent-rules \
	--disable-static \
	--docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc LICENSE
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files tools
%{_bindir}/*

%files -n python3-%{name}
%{python3_sitearch}/ixion.so

%changelog
* Thu Feb 15 2018 tchvatal@suse.com
- Rename python3 package to match up naming conventions
- Install license file
* Wed Nov 29 2017 tchvatal@suse.com
- Version update to 0.13.0:
  * Step lock update with orcus
  * Various fixes / fuzzer crashes resolved
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Dec  3 2016 tchvatal@suse.com
- Version update to 0.12.1:
  * Update to be in sync with orcus
  * Small fixes around
* Wed May 25 2016 tchvatal@suse.com
- Version update to 0.11.1:
  * Switch to mdds-1.2
  * Few small fixes
* Mon Mar  7 2016 tchvatal@suse.com
- Version update to 0.11.0:
  * Switch to mdds-1.0
  * Various fixes
  * Python3 bindings obsoleted python2 ones
* Mon Apr 13 2015 tchvatal@suse.com
- Version bump to 0.9.1:
  * various triv bugfixes
  * Build with tests and work this time
* Tue Mar 24 2015 tchvatal@suse.com
- Drop copy&pasto from fedora
* Tue Mar 24 2015 tchvatal@suse.com
- Version bump to 0.9.0:
  * Needed for new orcus
  * Python bindings are around now
- Update homepage
- Add python subpackage
- Tests fail with this release, next one will fix it again
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.7.0
  * needed by libreoffice 4.3.x
- Add pkgconfig(mdds) dependency instead of mdds-devel
* Sun Jan 26 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and make the outputs verbose.
* Wed May 15 2013 cfarrell@suse.com
- license update: MIT
  The SPDX shortname for the license described in the COPYING file is MIT
* Sat Apr 20 2013 tchvatal@suse.com
- Add URL path for the download.
- Update the package to be matching the released tarball.
- Do not force autoreconf as it is not really needed with released
  package.
* Wed Mar 27 2013 kyoshida@suse.com
- Updated the package which includes the boost patch and several
  others.
- Removed distro-specific patch.
* Tue Mar 26 2013 tchvatal@suse.com
- Cleanup a bit more for factory inclusion.
* Tue Mar 26 2013 jengelh@inai.de
- Fix wrong order of patch application and broken sed substitution
  in %%prep stage
- Runtime boost dependency is automatic and not needed
* Tue Mar 26 2013 tchvatal@suse.com
- Beautify a bit.
* Tue Mar 26 2013 tchvatal@suse.com
- Fix boost m4 macro to pass configure stage.
* Tue Mar 26 2013 kyoshida@suse.com
- Updated to the 0.5.0 pre-release version.
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Add autotools BuildRequires for factory/12.2
* Thu Oct 27 2011 kyoshida@suse.com
- Initial package.
